# HyPyUtils
 HyDEV Utils for Python

## Modules

| Module             | Requirements             |
|--------------------|--------------------------|
| `tqdm_utils`       | tqdm                     |
| `downloader`       | tqdm, requests           |
| `scientific_utils` | numpy, numba, matplotlib |
